@@ -6,10 +6,10 @@ import logging
 def handler(event, context):
     logger = logging.getLogger()
     logger.setLevel(logging.INFO)
-    command = f"/opt/awscli/aws emr-containers update-role-trust-policy --cluster-name {event['ResourceProperties']['eksClusterId']} --namespace {event['ResourceProperties']['eksNamespace']} --role-name {event['ResourceProperties']['roleName']}"
+    command = ["/opt/awscli/aws", "emr-containers", "update-role-trust-policy", "--cluster-name", f"{event['ResourceProperties']['eksClusterId']}", "--namespace", f"{event['ResourceProperties']['eksNamespace']}", "--role-name", f"{event['ResourceProperties']['roleName']}"]
     if event['RequestType'] == 'Create' or event['RequestType'] == 'Update' :
         try:
-            res = sp.check_output(command, shell=True)
+            res = sp.check_output(command)
             logger.info(f"Successfully ran {command}")
         except Exception as e:
             logger.info(f"ERROR: {str(e)}")
