@@ -10,10 +10,13 @@ import typing_extensions
 
 from typeguard import check_type
 
+import aws_cdk.asset_awscli_v1._jsii
+import aws_cdk.asset_kubectl_v20._jsii
+import aws_cdk.asset_node_proxy_agent_v5._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "aws-cdk-lib", "2.42.0", __name__[0:-6], "aws-cdk-lib@2.42.0.jsii.tgz"
+    "aws-cdk-lib", "2.74.0", __name__[0:-6], "aws-cdk-lib@2.74.0.jsii.tgz"
 )
 
 __all__ = [
