@@ -50,7 +50,7 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from .. import (
     CfnResource as _CfnResource_9df397a6,
     CfnTag as _CfnTag_f6864754,
@@ -107,14 +107,14 @@ class CfnProfilingGroup(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         profiling_group_name: builtins.str,
         agent_permissions: typing.Any = None,
-        anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[typing.Union["CfnProfilingGroup.ChannelProperty", typing.Dict[str, typing.Any]], _IResolvable_da3f097b]]]] = None,
+        anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnProfilingGroup.ChannelProperty", typing.Dict[builtins.str, typing.Any]]]]]] = None,
         compute_platform: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[str, typing.Any]]]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''Create a new ``AWS::CodeGuruProfiler::ProfilingGroup``.
 
@@ -127,7 +127,7 @@ class CfnProfilingGroup(
         :param tags: A list of tags to add to the created profiling group.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnProfilingGroup.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__c9aa0abb6bab44bc6d99509172735702ee5d874bf3f43241d8a04bc9b239b8bf)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnProfilingGroupProps(
@@ -147,7 +147,7 @@ class CfnProfilingGroup(
         :param inspector: - tree inspector to collect and process attributes.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnProfilingGroup.inspect)
+            type_hints = typing.get_type_hints(_typecheckingstub__24a556687187f3fa5c9bf014559a3a117b65e51abfce2431cb066434dd4eaa44)
             check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -160,7 +160,7 @@ class CfnProfilingGroup(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnProfilingGroup._render_properties)
+            type_hints = typing.get_type_hints(_typecheckingstub__fafc590c253689aa6dbe3ece2a14715971b41a0287ac3abea2185200d7448965)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -211,7 +211,7 @@ class CfnProfilingGroup(
     @agent_permissions.setter
     def agent_permissions(self, value: typing.Any) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnProfilingGroup, "agent_permissions").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__17d718bda323291cfa3fcddd8a1a5bb1086c9c8fc294cbc26895b278f35c89d1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "agentPermissions", value)
 
@@ -227,7 +227,7 @@ class CfnProfilingGroup(
     @profiling_group_name.setter
     def profiling_group_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnProfilingGroup, "profiling_group_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__c5573a5208adffdf4734f691eb4ff7539202b1db0e5b1ca78bff1b5df9d85c73)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "profilingGroupName", value)
 
@@ -235,20 +235,20 @@ class CfnProfilingGroup(
     @jsii.member(jsii_name="anomalyDetectionNotificationConfiguration")
     def anomaly_detection_notification_configuration(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union["CfnProfilingGroup.ChannelProperty", _IResolvable_da3f097b]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnProfilingGroup.ChannelProperty"]]]]:
         '''Adds anomaly notifications for a profiling group.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-anomalydetectionnotificationconfiguration
         '''
-        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union["CfnProfilingGroup.ChannelProperty", _IResolvable_da3f097b]]]], jsii.get(self, "anomalyDetectionNotificationConfiguration"))
+        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnProfilingGroup.ChannelProperty"]]]], jsii.get(self, "anomalyDetectionNotificationConfiguration"))
 
     @anomaly_detection_notification_configuration.setter
     def anomaly_detection_notification_configuration(
         self,
-        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union["CfnProfilingGroup.ChannelProperty", _IResolvable_da3f097b]]]],
+        value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnProfilingGroup.ChannelProperty"]]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnProfilingGroup, "anomaly_detection_notification_configuration").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__316c247cfa3a39c676bf4ce8b50310a7688cf6084a673ebde8f3462cb4464ee6)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "anomalyDetectionNotificationConfiguration", value)
 
@@ -266,10 +266,61 @@ class CfnProfilingGroup(
     @compute_platform.setter
     def compute_platform(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnProfilingGroup, "compute_platform").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__cb128be2e7cd15970dee2ea394d635c967fffc05335b5468f285d71eb7972df8)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "computePlatform", value)
 
+    @jsii.data_type(
+        jsii_type="aws-cdk-lib.aws_codeguruprofiler.CfnProfilingGroup.AgentPermissionsProperty",
+        jsii_struct_bases=[],
+        name_mapping={"principals": "principals"},
+    )
+    class AgentPermissionsProperty:
+        def __init__(self, *, principals: typing.Sequence[builtins.str]) -> None:
+            '''
+            :param principals: ``CfnProfilingGroup.AgentPermissionsProperty.Principals``.
+
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-agentpermissions.html
+            :exampleMetadata: fixture=_generated
+
+            Example::
+
+                # The code below shows an example of how to instantiate this type.
+                # The values are placeholders you should change.
+                from aws_cdk import aws_codeguruprofiler as codeguruprofiler
+                
+                agent_permissions_property = codeguruprofiler.CfnProfilingGroup.AgentPermissionsProperty(
+                    principals=["principals"]
+                )
+            '''
+            if __debug__:
+                type_hints = typing.get_type_hints(_typecheckingstub__811cebbf9ff71c6cdc0a3e6f6073b243f3749069770de9b6715845db6a859300)
+                check_type(argname="argument principals", value=principals, expected_type=type_hints["principals"])
+            self._values: typing.Dict[builtins.str, typing.Any] = {
+                "principals": principals,
+            }
+
+        @builtins.property
+        def principals(self) -> typing.List[builtins.str]:
+            '''``CfnProfilingGroup.AgentPermissionsProperty.Principals``.
+
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-agentpermissions.html#cfn-codeguruprofiler-profilinggroup-agentpermissions-principals
+            '''
+            result = self._values.get("principals")
+            assert result is not None, "Required property 'principals' is missing"
+            return typing.cast(typing.List[builtins.str], result)
+
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "AgentPermissionsProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
     @jsii.data_type(
         jsii_type="aws-cdk-lib.aws_codeguruprofiler.CfnProfilingGroup.ChannelProperty",
         jsii_struct_bases=[],
@@ -306,10 +357,10 @@ class CfnProfilingGroup(
                 )
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(CfnProfilingGroup.ChannelProperty.__init__)
+                type_hints = typing.get_type_hints(_typecheckingstub__897f8a8de60bab360ab0a19378aece0020e93e34fe48060c6e6eca85b77617e3)
                 check_type(argname="argument channel_uri", value=channel_uri, expected_type=type_hints["channel_uri"])
                 check_type(argname="argument channel_id", value=channel_id, expected_type=type_hints["channel_id"])
-            self._values: typing.Dict[str, typing.Any] = {
+            self._values: typing.Dict[builtins.str, typing.Any] = {
                 "channel_uri": channel_uri,
             }
             if channel_id is not None:
@@ -363,9 +414,9 @@ class CfnProfilingGroupProps:
         *,
         profiling_group_name: builtins.str,
         agent_permissions: typing.Any = None,
-        anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[typing.Union[CfnProfilingGroup.ChannelProperty, typing.Dict[str, typing.Any]], _IResolvable_da3f097b]]]] = None,
+        anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnProfilingGroup.ChannelProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
         compute_platform: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[str, typing.Any]]]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''Properties for defining a ``CfnProfilingGroup``.
 
@@ -405,13 +456,13 @@ class CfnProfilingGroupProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnProfilingGroupProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__b0311e48a474ca90384078ca3a0759f5a58ab45163d3da706301f20c5207756e)
             check_type(argname="argument profiling_group_name", value=profiling_group_name, expected_type=type_hints["profiling_group_name"])
             check_type(argname="argument agent_permissions", value=agent_permissions, expected_type=type_hints["agent_permissions"])
             check_type(argname="argument anomaly_detection_notification_configuration", value=anomaly_detection_notification_configuration, expected_type=type_hints["anomaly_detection_notification_configuration"])
             check_type(argname="argument compute_platform", value=compute_platform, expected_type=type_hints["compute_platform"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "profiling_group_name": profiling_group_name,
         }
         if agent_permissions is not None:
@@ -451,13 +502,13 @@ class CfnProfilingGroupProps:
     @builtins.property
     def anomaly_detection_notification_configuration(
         self,
-    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[CfnProfilingGroup.ChannelProperty, _IResolvable_da3f097b]]]]:
+    ) -> typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnProfilingGroup.ChannelProperty]]]]:
         '''Adds anomaly notifications for a profiling group.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-anomalydetectionnotificationconfiguration
         '''
         result = self._values.get("anomaly_detection_notification_configuration")
-        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[CfnProfilingGroup.ChannelProperty, _IResolvable_da3f097b]]]], result)
+        return typing.cast(typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnProfilingGroup.ChannelProperty]]]], result)
 
     @builtins.property
     def compute_platform(self) -> typing.Optional[builtins.str]:
@@ -514,10 +565,19 @@ class ComputePlatform(enum.Enum):
 class IProfilingGroup(_IResource_c80c4260, typing_extensions.Protocol):
     '''IResource represents a Profiling Group.'''
 
+    @builtins.property
+    @jsii.member(jsii_name="profilingGroupArn")
+    def profiling_group_arn(self) -> builtins.str:
+        '''The ARN of the profiling group.
+
+        :attribute: true
+        '''
+        ...
+
     @builtins.property
     @jsii.member(jsii_name="profilingGroupName")
     def profiling_group_name(self) -> builtins.str:
-        '''A name for the profiling group.
+        '''The name of the profiling group.
 
         :attribute: true
         '''
@@ -557,10 +617,19 @@ class _IProfilingGroupProxy(
 
     __jsii_type__: typing.ClassVar[str] = "aws-cdk-lib.aws_codeguruprofiler.IProfilingGroup"
 
+    @builtins.property
+    @jsii.member(jsii_name="profilingGroupArn")
+    def profiling_group_arn(self) -> builtins.str:
+        '''The ARN of the profiling group.
+
+        :attribute: true
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "profilingGroupArn"))
+
     @builtins.property
     @jsii.member(jsii_name="profilingGroupName")
     def profiling_group_name(self) -> builtins.str:
-        '''A name for the profiling group.
+        '''The name of the profiling group.
 
         :attribute: true
         '''
@@ -578,7 +647,7 @@ class _IProfilingGroupProxy(
         :param grantee: Principal to grant publish rights to.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IProfilingGroup.grant_publish)
+            type_hints = typing.get_type_hints(_typecheckingstub__8eef65bccc91bd6f83597064fade053f490648802b0350f9227188dc1487b758)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(_Grant_a7ae64f8, jsii.invoke(self, "grantPublish", [grantee]))
 
@@ -594,7 +663,7 @@ class _IProfilingGroupProxy(
         :param grantee: Principal to grant read rights to.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IProfilingGroup.grant_read)
+            type_hints = typing.get_type_hints(_typecheckingstub__fad88677a83439824b5289f835fd0b41a038abaadbb21252ece4a01a245e1033)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(_Grant_a7ae64f8, jsii.invoke(self, "grantRead", [grantee]))
 
@@ -625,7 +694,7 @@ class ProfilingGroup(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         compute_platform: typing.Optional[ComputePlatform] = None,
@@ -638,7 +707,7 @@ class ProfilingGroup(
         :param profiling_group_name: A name for the profiling group. Default: - automatically generated name.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProfilingGroup.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__455d9f8e0fda8271257c6c1025ea87ea065d36bfefe7d63f702c45b526cc1976)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ProfilingGroupProps(
@@ -652,7 +721,7 @@ class ProfilingGroup(
     @builtins.classmethod
     def from_profiling_group_arn(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         profiling_group_arn: builtins.str,
     ) -> IProfilingGroup:
@@ -663,7 +732,7 @@ class ProfilingGroup(
         :param profiling_group_arn: Profiling Group ARN.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProfilingGroup.from_profiling_group_arn)
+            type_hints = typing.get_type_hints(_typecheckingstub__b91b6e9dff0c314a77924dad57869cdc71781e124518a42fbbb57612c6f29d4b)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument profiling_group_arn", value=profiling_group_arn, expected_type=type_hints["profiling_group_arn"])
@@ -673,7 +742,7 @@ class ProfilingGroup(
     @builtins.classmethod
     def from_profiling_group_name(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         profiling_group_name: builtins.str,
     ) -> IProfilingGroup:
@@ -684,7 +753,7 @@ class ProfilingGroup(
         :param profiling_group_name: Profiling Group Name.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProfilingGroup.from_profiling_group_name)
+            type_hints = typing.get_type_hints(_typecheckingstub__833a9e7894a97394ac1565daa3d417cd81e363776254c84ac034b459e478c491)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument profiling_group_name", value=profiling_group_name, expected_type=type_hints["profiling_group_name"])
@@ -702,7 +771,7 @@ class ProfilingGroup(
         :param grantee: Principal to grant publish rights to.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProfilingGroup.grant_publish)
+            type_hints = typing.get_type_hints(_typecheckingstub__18fa54053affb91d59e1ada2098754620fc3f0b31a3be3a82e08a29b665655f4)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(_Grant_a7ae64f8, jsii.invoke(self, "grantPublish", [grantee]))
 
@@ -718,7 +787,7 @@ class ProfilingGroup(
         :param grantee: Principal to grant read rights to.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProfilingGroup.grant_read)
+            type_hints = typing.get_type_hints(_typecheckingstub__23cf99a24a4b56d46b427eae23b846bdf8f4365553fa7bd0efc8267f78934894)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(_Grant_a7ae64f8, jsii.invoke(self, "grantRead", [grantee]))
 
@@ -770,10 +839,10 @@ class ProfilingGroupProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ProfilingGroupProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__b4843108164af294aabe875088a5b93297a7983cba8b4e8af4a9bcae0fb6659c)
             check_type(argname="argument compute_platform", value=compute_platform, expected_type=type_hints["compute_platform"])
             check_type(argname="argument profiling_group_name", value=profiling_group_name, expected_type=type_hints["profiling_group_name"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if compute_platform is not None:
             self._values["compute_platform"] = compute_platform
         if profiling_group_name is not None:
@@ -819,3 +888,136 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__c9aa0abb6bab44bc6d99509172735702ee5d874bf3f43241d8a04bc9b239b8bf(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    profiling_group_name: builtins.str,
+    agent_permissions: typing.Any = None,
+    anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnProfilingGroup.ChannelProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
+    compute_platform: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__24a556687187f3fa5c9bf014559a3a117b65e51abfce2431cb066434dd4eaa44(
+    inspector: _TreeInspector_488e0dd5,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fafc590c253689aa6dbe3ece2a14715971b41a0287ac3abea2185200d7448965(
+    props: typing.Mapping[builtins.str, typing.Any],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__17d718bda323291cfa3fcddd8a1a5bb1086c9c8fc294cbc26895b278f35c89d1(
+    value: typing.Any,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c5573a5208adffdf4734f691eb4ff7539202b1db0e5b1ca78bff1b5df9d85c73(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__316c247cfa3a39c676bf4ce8b50310a7688cf6084a673ebde8f3462cb4464ee6(
+    value: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnProfilingGroup.ChannelProperty]]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cb128be2e7cd15970dee2ea394d635c967fffc05335b5468f285d71eb7972df8(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__811cebbf9ff71c6cdc0a3e6f6073b243f3749069770de9b6715845db6a859300(
+    *,
+    principals: typing.Sequence[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__897f8a8de60bab360ab0a19378aece0020e93e34fe48060c6e6eca85b77617e3(
+    *,
+    channel_uri: builtins.str,
+    channel_id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b0311e48a474ca90384078ca3a0759f5a58ab45163d3da706301f20c5207756e(
+    *,
+    profiling_group_name: builtins.str,
+    agent_permissions: typing.Any = None,
+    anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnProfilingGroup.ChannelProperty, typing.Dict[builtins.str, typing.Any]]]]]] = None,
+    compute_platform: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_f6864754, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8eef65bccc91bd6f83597064fade053f490648802b0350f9227188dc1487b758(
+    grantee: _IGrantable_71c4f5de,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fad88677a83439824b5289f835fd0b41a038abaadbb21252ece4a01a245e1033(
+    grantee: _IGrantable_71c4f5de,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__455d9f8e0fda8271257c6c1025ea87ea065d36bfefe7d63f702c45b526cc1976(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    compute_platform: typing.Optional[ComputePlatform] = None,
+    profiling_group_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b91b6e9dff0c314a77924dad57869cdc71781e124518a42fbbb57612c6f29d4b(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    profiling_group_arn: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__833a9e7894a97394ac1565daa3d417cd81e363776254c84ac034b459e478c491(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    profiling_group_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__18fa54053affb91d59e1ada2098754620fc3f0b31a3be3a82e08a29b665655f4(
+    grantee: _IGrantable_71c4f5de,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__23cf99a24a4b56d46b427eae23b846bdf8f4365553fa7bd0efc8267f78934894(
+    grantee: _IGrantable_71c4f5de,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b4843108164af294aabe875088a5b93297a7983cba8b4e8af4a9bcae0fb6659c(
+    *,
+    compute_platform: typing.Optional[ComputePlatform] = None,
+    profiling_group_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
