@@ -118,21 +118,24 @@ method `tryBundle()` which should return `true` if local bundling was performed.
 If `false` is returned, docker bundling will be done:
 
 ```python
-@jsii.implements(ILocalBundling)
+import aws_cdk as cdk
+
+
+@jsii.implements(cdk.ILocalBundling)
 class MyBundle:
-    def try_bundle(self, output_dir, *, image, entrypoint=None, command=None, volumes=None, environment=None, workingDirectory=None, user=None, local=None, outputType=None, securityOpt=None, network=None):
+    def try_bundle(self, output_dir, *, image, entrypoint=None, command=None, volumes=None, volumesFrom=None, environment=None, workingDirectory=None, user=None, local=None, outputType=None, securityOpt=None, network=None, bundlingFileAccess=None):
         can_run_locally = True # replace with actual logic
         if can_run_locally:
             # perform local bundling here
             return True
         return False
 
-assets.Asset(self, "BundledAsset",
+Asset(self, "BundledAsset",
     path="/path/to/asset",
-    bundling=BundlingOptions(
+    bundling=cdk.BundlingOptions(
         local=MyBundle(),
         # Docker bundling fallback
-        image=DockerImage.from_registry("alpine"),
+        image=cdk.DockerImage.from_registry("alpine"),
         entrypoint=["/bin/sh", "-c"],
         command=["bundle"]
     )
@@ -150,12 +153,15 @@ is the default behavior for `bundling.outputType` (`BundlingOutput.AUTO_DISCOVER
 Use `BundlingOutput.NOT_ARCHIVED` if the bundling output must always be zipped:
 
 ```python
-asset = assets.Asset(self, "BundledAsset",
+import aws_cdk as cdk
+
+
+asset = Asset(self, "BundledAsset",
     path="/path/to/asset",
-    bundling=BundlingOptions(
-        image=DockerImage.from_registry("alpine"),
+    bundling=cdk.BundlingOptions(
+        image=cdk.DockerImage.from_registry("alpine"),
         command=["command-that-produces-an-archive.sh"],
-        output_type=BundlingOutput.NOT_ARCHIVED
+        output_type=cdk.BundlingOutput.NOT_ARCHIVED
     )
 )
 ```
@@ -171,11 +177,13 @@ This can be done using [BundlingOptions](https://docs.aws.amazon.com/cdk/api/v2/
 Some optional properties to pass to the docker bundling
 
 ```python
-# Example automatically generated from non-compiling source. May contain errors.
-asset = assets.Asset(self, "BundledAsset",
+import aws_cdk.aws_lambda as lambda_
+
+
+asset = Asset(self, "BundledAsset",
     path="/path/to/asset",
     bundling=BundlingOptions(
-        image=ambda.Runtime.PYTHON_3_9.bundling_image,
+        image=lambda_.Runtime.PYTHON_3_9.bundling_image,
         command=["bash", "-c", "pip install -r requirements.txt -t /asset-output && cp -au . /asset-output"
         ],
         security_opt="no-new-privileges:true",  # https://docs.docker.com/engine/reference/commandline/run/#optional-security-options---security-opt
@@ -220,7 +228,7 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from .. import (
     AssetHashType as _AssetHashType_05b67f2d,
     AssetOptions as _AssetOptions_9cd3031e,
@@ -237,38 +245,39 @@ from ..aws_s3 import IBucket as _IBucket_42e086fd
 
 @jsii.implements(_IAsset_03c624d8)
 class Asset(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="aws-cdk-lib.aws_s3_assets.Asset",
 ):
     '''An asset represents a local file or directory, which is automatically uploaded to S3 and then can be referenced within a CDK application.
 
-    :exampleMetadata: lit=aws-s3-assets/test/integ.assets.bundling.lit.ts infused
+    :exampleMetadata: infused
 
     Example::
 
-        asset = assets.Asset(self, "BundledAsset",
-            path=path.join(__dirname, "markdown-asset"),  # /asset-input and working directory in the container
-            bundling=assets.BundlingOptions(
-                image=DockerImage.from_build(path.join(__dirname, "alpine-markdown")),  # Build an image
-                command=["sh", "-c", """
-                                markdown index.md > /asset-output/index.html
-                              """
-                ]
+        import aws_cdk as cdk
+        
+        
+        asset = Asset(self, "BundledAsset",
+            path="/path/to/asset",
+            bundling=cdk.BundlingOptions(
+                image=cdk.DockerImage.from_registry("alpine"),
+                command=["command-that-produces-an-archive.sh"],
+                output_type=cdk.BundlingOutput.NOT_ARCHIVED
             )
         )
     '''
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         path: builtins.str,
         readers: typing.Optional[typing.Sequence[_IGrantable_71c4f5de]] = None,
         asset_hash: typing.Optional[builtins.str] = None,
         asset_hash_type: typing.Optional[_AssetHashType_05b67f2d] = None,
-        bundling: typing.Optional[typing.Union[_BundlingOptions_588cc936, typing.Dict[str, typing.Any]]] = None,
+        bundling: typing.Optional[typing.Union[_BundlingOptions_588cc936, typing.Dict[builtins.str, typing.Any]]] = None,
         exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
         follow_symlinks: typing.Optional[_SymlinkFollowMode_047ec1f6] = None,
         ignore_mode: typing.Optional[_IgnoreMode_655a98e8] = None,
@@ -286,7 +295,7 @@ class Asset(
         :param ignore_mode: The ignore behavior to use for ``exclude`` patterns. Default: IgnoreMode.GLOB
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Asset.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__00df81fd3b746cf2ee52c0e7a23b6fdc1b45db97673ca7e25a9651e7e2a4976b)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = AssetProps(
@@ -323,7 +332,7 @@ class Asset(
         :see: https://github.com/aws/aws-cdk/issues/1432
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Asset.add_resource_metadata)
+            type_hints = typing.get_type_hints(_typecheckingstub__f61a6eb6ec5bb9c8f9b7933979f88a1fc68820ccc4cc76a663b24d3c48e7d036)
             check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
             check_type(argname="argument resource_property", value=resource_property, expected_type=type_hints["resource_property"])
         return typing.cast(None, jsii.invoke(self, "addResourceMetadata", [resource, resource_property]))
@@ -335,7 +344,7 @@ class Asset(
         :param grantee: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Asset.grant_read)
+            type_hints = typing.get_type_hints(_typecheckingstub__c6425d5070c191fc82b7882c0028ef6e8289f1fb411fbbc4209d20b31eddc229)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(None, jsii.invoke(self, "grantRead", [grantee]))
 
@@ -436,7 +445,7 @@ class AssetOptions(_AssetOptions_9cd3031e, _FileCopyOptions_e03e2a30):
         *,
         asset_hash: typing.Optional[builtins.str] = None,
         asset_hash_type: typing.Optional[_AssetHashType_05b67f2d] = None,
-        bundling: typing.Optional[typing.Union[_BundlingOptions_588cc936, typing.Dict[str, typing.Any]]] = None,
+        bundling: typing.Optional[typing.Union[_BundlingOptions_588cc936, typing.Dict[builtins.str, typing.Any]]] = None,
         exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
         follow_symlinks: typing.Optional[_SymlinkFollowMode_047ec1f6] = None,
         ignore_mode: typing.Optional[_IgnoreMode_655a98e8] = None,
@@ -470,7 +479,7 @@ class AssetOptions(_AssetOptions_9cd3031e, _FileCopyOptions_e03e2a30):
         if isinstance(bundling, dict):
             bundling = _BundlingOptions_588cc936(**bundling)
         if __debug__:
-            type_hints = typing.get_type_hints(AssetOptions.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__11950fe0327642dd25ddfeb2c620bb33847718475fe489bf003d096a07e81b69)
             check_type(argname="argument asset_hash", value=asset_hash, expected_type=type_hints["asset_hash"])
             check_type(argname="argument asset_hash_type", value=asset_hash_type, expected_type=type_hints["asset_hash_type"])
             check_type(argname="argument bundling", value=bundling, expected_type=type_hints["bundling"])
@@ -478,7 +487,7 @@ class AssetOptions(_AssetOptions_9cd3031e, _FileCopyOptions_e03e2a30):
             check_type(argname="argument follow_symlinks", value=follow_symlinks, expected_type=type_hints["follow_symlinks"])
             check_type(argname="argument ignore_mode", value=ignore_mode, expected_type=type_hints["ignore_mode"])
             check_type(argname="argument readers", value=readers, expected_type=type_hints["readers"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if asset_hash is not None:
             self._values["asset_hash"] = asset_hash
         if asset_hash_type is not None:
@@ -619,7 +628,7 @@ class AssetProps(AssetOptions):
         *,
         asset_hash: typing.Optional[builtins.str] = None,
         asset_hash_type: typing.Optional[_AssetHashType_05b67f2d] = None,
-        bundling: typing.Optional[typing.Union[_BundlingOptions_588cc936, typing.Dict[str, typing.Any]]] = None,
+        bundling: typing.Optional[typing.Union[_BundlingOptions_588cc936, typing.Dict[builtins.str, typing.Any]]] = None,
         exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
         follow_symlinks: typing.Optional[_SymlinkFollowMode_047ec1f6] = None,
         ignore_mode: typing.Optional[_IgnoreMode_655a98e8] = None,
@@ -636,25 +645,26 @@ class AssetProps(AssetOptions):
         :param readers: A list of principals that should be able to read this asset from S3. You can use ``asset.grantRead(principal)`` to grant read permissions later. Default: - No principals that can read file asset.
         :param path: The disk location of the asset. The path should refer to one of the following: - A regular file or a .zip file, in which case the file will be uploaded as-is to S3. - A directory, in which case it will be archived into a .zip file and uploaded to S3.
 
-        :exampleMetadata: lit=aws-s3-assets/test/integ.assets.bundling.lit.ts infused
+        :exampleMetadata: infused
 
         Example::
 
-            asset = assets.Asset(self, "BundledAsset",
-                path=path.join(__dirname, "markdown-asset"),  # /asset-input and working directory in the container
-                bundling=assets.BundlingOptions(
-                    image=DockerImage.from_build(path.join(__dirname, "alpine-markdown")),  # Build an image
-                    command=["sh", "-c", """
-                                    markdown index.md > /asset-output/index.html
-                                  """
-                    ]
+            import aws_cdk as cdk
+            
+            
+            asset = Asset(self, "BundledAsset",
+                path="/path/to/asset",
+                bundling=cdk.BundlingOptions(
+                    image=cdk.DockerImage.from_registry("alpine"),
+                    command=["command-that-produces-an-archive.sh"],
+                    output_type=cdk.BundlingOutput.NOT_ARCHIVED
                 )
             )
         '''
         if isinstance(bundling, dict):
             bundling = _BundlingOptions_588cc936(**bundling)
         if __debug__:
-            type_hints = typing.get_type_hints(AssetProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__f879318d3885bc2e9c71c124fac7ad5a955812e438be7c03244c3aad7bda9fbe)
             check_type(argname="argument asset_hash", value=asset_hash, expected_type=type_hints["asset_hash"])
             check_type(argname="argument asset_hash_type", value=asset_hash_type, expected_type=type_hints["asset_hash_type"])
             check_type(argname="argument bundling", value=bundling, expected_type=type_hints["bundling"])
@@ -663,7 +673,7 @@ class AssetProps(AssetOptions):
             check_type(argname="argument ignore_mode", value=ignore_mode, expected_type=type_hints["ignore_mode"])
             check_type(argname="argument readers", value=readers, expected_type=type_hints["readers"])
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "path": path,
         }
         if asset_hash is not None:
@@ -806,3 +816,59 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__00df81fd3b746cf2ee52c0e7a23b6fdc1b45db97673ca7e25a9651e7e2a4976b(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    path: builtins.str,
+    readers: typing.Optional[typing.Sequence[_IGrantable_71c4f5de]] = None,
+    asset_hash: typing.Optional[builtins.str] = None,
+    asset_hash_type: typing.Optional[_AssetHashType_05b67f2d] = None,
+    bundling: typing.Optional[typing.Union[_BundlingOptions_588cc936, typing.Dict[builtins.str, typing.Any]]] = None,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    follow_symlinks: typing.Optional[_SymlinkFollowMode_047ec1f6] = None,
+    ignore_mode: typing.Optional[_IgnoreMode_655a98e8] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f61a6eb6ec5bb9c8f9b7933979f88a1fc68820ccc4cc76a663b24d3c48e7d036(
+    resource: _CfnResource_9df397a6,
+    resource_property: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c6425d5070c191fc82b7882c0028ef6e8289f1fb411fbbc4209d20b31eddc229(
+    grantee: _IGrantable_71c4f5de,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__11950fe0327642dd25ddfeb2c620bb33847718475fe489bf003d096a07e81b69(
+    *,
+    asset_hash: typing.Optional[builtins.str] = None,
+    asset_hash_type: typing.Optional[_AssetHashType_05b67f2d] = None,
+    bundling: typing.Optional[typing.Union[_BundlingOptions_588cc936, typing.Dict[builtins.str, typing.Any]]] = None,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    follow_symlinks: typing.Optional[_SymlinkFollowMode_047ec1f6] = None,
+    ignore_mode: typing.Optional[_IgnoreMode_655a98e8] = None,
+    readers: typing.Optional[typing.Sequence[_IGrantable_71c4f5de]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f879318d3885bc2e9c71c124fac7ad5a955812e438be7c03244c3aad7bda9fbe(
+    *,
+    asset_hash: typing.Optional[builtins.str] = None,
+    asset_hash_type: typing.Optional[_AssetHashType_05b67f2d] = None,
+    bundling: typing.Optional[typing.Union[_BundlingOptions_588cc936, typing.Dict[builtins.str, typing.Any]]] = None,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    follow_symlinks: typing.Optional[_SymlinkFollowMode_047ec1f6] = None,
+    ignore_mode: typing.Optional[_IgnoreMode_655a98e8] = None,
+    readers: typing.Optional[typing.Sequence[_IGrantable_71c4f5de]] = None,
+    path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
