@@ -53,6 +53,21 @@ ConstructThatReadsFromTheBucket(self, "Consumer", {
 })
 ```
 
+It is also possible to add additional sources using the `addSource` method.
+
+```python
+# website_bucket: s3.IBucket
+
+
+deployment = s3deploy.BucketDeployment(self, "DeployWebsite",
+    sources=[s3deploy.Source.asset("./website-dist")],
+    destination_bucket=website_bucket,
+    destination_key_prefix="web/static"
+)
+
+deployment.add_source(s3deploy.Source.asset("./another-asset"))
+```
+
 ## Supported sources
 
 The following source types are supported for bucket deployments:
@@ -64,6 +79,8 @@ The following source types are supported for bucket deployments:
   (supports [deploy-time values](#data-with-deploy-time-values))
 * JSON data: `s3deploy.Source.jsonData('object-key.json', { json: 'object' })`
   (supports [deploy-time values](#data-with-deploy-time-values))
+* YAML data: `s3deploy.Source.yamlData('object-key.yaml', { yaml: 'object' })`
+  (supports [deploy-time values](#data-with-deploy-time-values))
 
 To create a source from a single file, you can pass `AssetOptions` to exclude
 all but a single file:
@@ -217,7 +234,7 @@ s3deploy.BucketDeployment(self, "DeployWebsite",
     sources=[s3deploy.Source.asset("./website-dist")],
     destination_bucket=website_bucket,
     destination_key_prefix="web/static",  # optional prefix in destination bucket
-    metadata=s3deploy.UserDefinedObjectMetadata(A="1", b="2"),  # user-defined metadata
+    metadata={"A": "1", "b": "2"},  # user-defined metadata
 
     # system-defined metadata
     content_type="text/html",
@@ -296,7 +313,7 @@ s3deploy.BucketDeployment(self, "DeployMeWithEfsStorage",
 
 ## Data with deploy-time values
 
-The content passed to `Source.data()` or `Source.jsonData()` can include
+The content passed to `Source.data()`, `Source.jsonData()`, or `Source.yamlData()` can include
 references that will get resolved only during deployment.
 
 For example:
@@ -323,6 +340,29 @@ The value in `topic.topicArn` is a deploy-time value. It only gets resolved
 during deployment by placing a marker in the generated source file and
 substituting it when its deployed to the destination with the actual value.
 
+## Keep Files Zipped
+
+By default, files are zipped, then extracted into the destination bucket.
+
+You can use the option `extract: false` to disable this behavior, in which case, files will remain in a zip file when deployed to S3. To reference the object keys, or filenames, which will be deployed to the bucket, you can use the `objectKeys` getter on the bucket deployment.
+
+```python
+import aws_cdk as cdk
+
+# destination_bucket: s3.Bucket
+
+
+my_bucket_deployment = s3deploy.BucketDeployment(self, "DeployMeWithoutExtractingFilesOnDestination",
+    sources=[s3deploy.Source.asset(path.join(__dirname, "my-website"))],
+    destination_bucket=destination_bucket,
+    extract=False
+)
+
+cdk.CfnOutput(self, "ObjectKey",
+    value=cdk.Fn.select(0, my_bucket_deployment.object_keys)
+)
+```
+
 ## Notes
 
 * This library uses an AWS CloudFormation custom resource which is about 10MiB in
@@ -343,11 +383,11 @@ substituting it when its deployed to the destination with the actual value.
 
 ## Development
 
-The custom resource is implemented in Python 3.7 in order to be able to leverage
+The custom resource is implemented in Python 3.9 in order to be able to leverage
 the AWS CLI for "aws s3 sync". The code is under [`lib/lambda`](https://github.com/aws/aws-cdk/tree/main/packages/%40aws-cdk/aws-s3-deployment/lib/lambda) and
 unit tests are under [`test/lambda`](https://github.com/aws/aws-cdk/tree/main/packages/%40aws-cdk/aws-s3-deployment/test/lambda).
 
-This package requires Python 3.7 during build time in order to create the custom
+This package requires Python 3.9 during build time in order to create the custom
 resource Lambda bundle and test it. It also relies on a few bash scripts, so
 might be tricky to build on Windows.
 
@@ -369,7 +409,7 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from .. import (
     AssetHashType as _AssetHashType_05b67f2d,
     BundlingOptions as _BundlingOptions_588cc936,
@@ -392,7 +432,7 @@ from ..aws_s3_assets import AssetOptions as _AssetOptions_2aa69621
 
 
 class BucketDeployment(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="aws-cdk-lib.aws_s3_deployment.BucketDeployment",
 ):
@@ -418,7 +458,7 @@ class BucketDeployment(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         destination_bucket: _IBucket_42e086fd,
@@ -435,10 +475,11 @@ class BucketDeployment(
         ephemeral_storage_size: typing.Optional[_Size_7b441c34] = None,
         exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
         expires: typing.Optional[_Expiration_059d47d0] = None,
+        extract: typing.Optional[builtins.bool] = None,
         include: typing.Optional[typing.Sequence[builtins.str]] = None,
         log_retention: typing.Optional[_RetentionDays_070f99f0] = None,
         memory_limit: typing.Optional[jsii.Number] = None,
-        metadata: typing.Optional[typing.Union["UserDefinedObjectMetadata", typing.Dict[str, typing.Any]]] = None,
+        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         prune: typing.Optional[builtins.bool] = None,
         retain_on_delete: typing.Optional[builtins.bool] = None,
         role: typing.Optional[_IRole_235f5d8e] = None,
@@ -448,7 +489,7 @@ class BucketDeployment(
         storage_class: typing.Optional["StorageClass"] = None,
         use_efs: typing.Optional[builtins.bool] = None,
         vpc: typing.Optional[_IVpc_f30d5663] = None,
-        vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[str, typing.Any]]] = None,
+        vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[builtins.str, typing.Any]]] = None,
         website_redirect_location: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -468,6 +509,7 @@ class BucketDeployment(
         :param ephemeral_storage_size: The size of the AWS Lambda function’s /tmp directory in MiB. Default: 512 MiB
         :param exclude: If this is set, matching files or objects will be excluded from the deployment's sync command. This can be used to exclude a file from being pruned in the destination bucket. If you want to just exclude files from the deployment package (which excludes these files evaluated when invalidating the asset), you should leverage the ``exclude`` property of ``AssetOptions`` when defining your source. Default: - No exclude filters are used
         :param expires: System-defined expires metadata to be set on all objects in the deployment. Default: - The objects in the distribution will not expire.
+        :param extract: If this is set, the zip file will be synced to the destination S3 bucket and extracted. If false, the file will remain zipped in the destination bucket. Default: true
         :param include: If this is set, matching files or objects will be included with the deployment's sync command. Since all files from the deployment package are included by default, this property is usually leveraged alongside an ``exclude`` filter. Default: - No include filters are used and all files are included with the sync command
         :param log_retention: The number of days that the lambda function's log events are kept in CloudWatch Logs. Default: logs.RetentionDays.INFINITE
         :param memory_limit: The amount of memory (in MiB) to allocate to the AWS Lambda function which replicates the files from the CDK bucket to the destination bucket. If you are deploying large files, you will need to increase this number accordingly. Default: 128
@@ -485,7 +527,7 @@ class BucketDeployment(
         :param website_redirect_location: System-defined x-amz-website-redirect-location metadata to be set on all objects in the deployment. Default: - No website redirection.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(BucketDeployment.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__2544491e92aa50a255b927ef16b9cde2961eae48803afca3b5d1105bfc3398f1)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = BucketDeploymentProps(
@@ -503,6 +545,7 @@ class BucketDeployment(
             ephemeral_storage_size=ephemeral_storage_size,
             exclude=exclude,
             expires=expires,
+            extract=extract,
             include=include,
             log_retention=log_retention,
             memory_limit=memory_limit,
@@ -522,6 +565,28 @@ class BucketDeployment(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
+    @jsii.member(jsii_name="addSource")
+    def add_source(self, source: "ISource") -> None:
+        '''Add an additional source to the bucket deployment.
+
+        :param source: -
+
+        Example::
+
+            # website_bucket: s3.IBucket
+            
+            deployment = s3deploy.BucketDeployment(self, "Deployment",
+                sources=[s3deploy.Source.asset("./website-dist")],
+                destination_bucket=website_bucket
+            )
+            
+            deployment.add_source(s3deploy.Source.asset("./another-asset"))
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__cfc987787f1589c85fbb65eaf66aaf15684268f9d214e1a0278f52c99e907028)
+            check_type(argname="argument source", value=source, expected_type=type_hints["source"])
+        return typing.cast(None, jsii.invoke(self, "addSource", [source]))
+
     @builtins.property
     @jsii.member(jsii_name="deployedBucket")
     def deployed_bucket(self) -> _IBucket_42e086fd:
@@ -531,10 +596,28 @@ class BucketDeployment(
         bucket deployment has happened before the next operation is started, pass the other construct
         a reference to ``deployment.deployedBucket``.
 
-        Doing this replaces calling ``otherResource.node.addDependency(deployment)``.
+        Note that this only returns an immutable reference to the destination bucket.
+        If sequenced access to the original destination bucket is required, you may add a dependency
+        on the bucket deployment instead: ``otherResource.node.addDependency(deployment)``
         '''
         return typing.cast(_IBucket_42e086fd, jsii.get(self, "deployedBucket"))
 
+    @builtins.property
+    @jsii.member(jsii_name="objectKeys")
+    def object_keys(self) -> typing.List[builtins.str]:
+        '''The object keys for the sources deployed to the S3 bucket.
+
+        This returns a list of tokenized object keys for source files that are deployed to the bucket.
+
+        This can be useful when using ``BucketDeployment`` with ``extract`` set to ``false`` and you need to reference
+        the object key that resides in the bucket for that zip source file somewhere else in your CDK
+        application, such as in a CFN output.
+
+        For example, use ``Fn.select(0, myBucketDeployment.objectKeys)`` to reference the object key of the
+        first source file in your bucket deployment.
+        '''
+        return typing.cast(typing.List[builtins.str], jsii.get(self, "objectKeys"))
+
 
 @jsii.data_type(
     jsii_type="aws-cdk-lib.aws_s3_deployment.BucketDeploymentProps",
@@ -554,6 +637,7 @@ class BucketDeployment(
         "ephemeral_storage_size": "ephemeralStorageSize",
         "exclude": "exclude",
         "expires": "expires",
+        "extract": "extract",
         "include": "include",
         "log_retention": "logRetention",
         "memory_limit": "memoryLimit",
@@ -589,10 +673,11 @@ class BucketDeploymentProps:
         ephemeral_storage_size: typing.Optional[_Size_7b441c34] = None,
         exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
         expires: typing.Optional[_Expiration_059d47d0] = None,
+        extract: typing.Optional[builtins.bool] = None,
         include: typing.Optional[typing.Sequence[builtins.str]] = None,
         log_retention: typing.Optional[_RetentionDays_070f99f0] = None,
         memory_limit: typing.Optional[jsii.Number] = None,
-        metadata: typing.Optional[typing.Union["UserDefinedObjectMetadata", typing.Dict[str, typing.Any]]] = None,
+        metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         prune: typing.Optional[builtins.bool] = None,
         retain_on_delete: typing.Optional[builtins.bool] = None,
         role: typing.Optional[_IRole_235f5d8e] = None,
@@ -602,7 +687,7 @@ class BucketDeploymentProps:
         storage_class: typing.Optional["StorageClass"] = None,
         use_efs: typing.Optional[builtins.bool] = None,
         vpc: typing.Optional[_IVpc_f30d5663] = None,
-        vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[str, typing.Any]]] = None,
+        vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[builtins.str, typing.Any]]] = None,
         website_redirect_location: typing.Optional[builtins.str] = None,
     ) -> None:
         '''Properties for ``BucketDeployment``.
@@ -621,6 +706,7 @@ class BucketDeploymentProps:
         :param ephemeral_storage_size: The size of the AWS Lambda function’s /tmp directory in MiB. Default: 512 MiB
         :param exclude: If this is set, matching files or objects will be excluded from the deployment's sync command. This can be used to exclude a file from being pruned in the destination bucket. If you want to just exclude files from the deployment package (which excludes these files evaluated when invalidating the asset), you should leverage the ``exclude`` property of ``AssetOptions`` when defining your source. Default: - No exclude filters are used
         :param expires: System-defined expires metadata to be set on all objects in the deployment. Default: - The objects in the distribution will not expire.
+        :param extract: If this is set, the zip file will be synced to the destination S3 bucket and extracted. If false, the file will remain zipped in the destination bucket. Default: true
         :param include: If this is set, matching files or objects will be included with the deployment's sync command. Since all files from the deployment package are included by default, this property is usually leveraged alongside an ``exclude`` filter. Default: - No include filters are used and all files are included with the sync command
         :param log_retention: The number of days that the lambda function's log events are kept in CloudWatch Logs. Default: logs.RetentionDays.INFINITE
         :param memory_limit: The amount of memory (in MiB) to allocate to the AWS Lambda function which replicates the files from the CDK bucket to the destination bucket. If you are deploying large files, you will need to increase this number accordingly. Default: 128
@@ -654,12 +740,10 @@ class BucketDeploymentProps:
                 "bucket": deployment.deployed_bucket
             })
         '''
-        if isinstance(metadata, dict):
-            metadata = UserDefinedObjectMetadata(**metadata)
         if isinstance(vpc_subnets, dict):
             vpc_subnets = _SubnetSelection_e57d76df(**vpc_subnets)
         if __debug__:
-            type_hints = typing.get_type_hints(BucketDeploymentProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__cbabf07e8b4adfb2b2058c075c4f35512ebc580f80a6db9bf13e905898822551)
             check_type(argname="argument destination_bucket", value=destination_bucket, expected_type=type_hints["destination_bucket"])
             check_type(argname="argument sources", value=sources, expected_type=type_hints["sources"])
             check_type(argname="argument access_control", value=access_control, expected_type=type_hints["access_control"])
@@ -674,6 +758,7 @@ class BucketDeploymentProps:
             check_type(argname="argument ephemeral_storage_size", value=ephemeral_storage_size, expected_type=type_hints["ephemeral_storage_size"])
             check_type(argname="argument exclude", value=exclude, expected_type=type_hints["exclude"])
             check_type(argname="argument expires", value=expires, expected_type=type_hints["expires"])
+            check_type(argname="argument extract", value=extract, expected_type=type_hints["extract"])
             check_type(argname="argument include", value=include, expected_type=type_hints["include"])
             check_type(argname="argument log_retention", value=log_retention, expected_type=type_hints["log_retention"])
             check_type(argname="argument memory_limit", value=memory_limit, expected_type=type_hints["memory_limit"])
@@ -689,7 +774,7 @@ class BucketDeploymentProps:
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
             check_type(argname="argument vpc_subnets", value=vpc_subnets, expected_type=type_hints["vpc_subnets"])
             check_type(argname="argument website_redirect_location", value=website_redirect_location, expected_type=type_hints["website_redirect_location"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "destination_bucket": destination_bucket,
             "sources": sources,
         }
@@ -717,6 +802,8 @@ class BucketDeploymentProps:
             self._values["exclude"] = exclude
         if expires is not None:
             self._values["expires"] = expires
+        if extract is not None:
+            self._values["extract"] = extract
         if include is not None:
             self._values["include"] = include
         if log_retention is not None:
@@ -897,6 +984,17 @@ class BucketDeploymentProps:
         result = self._values.get("expires")
         return typing.cast(typing.Optional[_Expiration_059d47d0], result)
 
+    @builtins.property
+    def extract(self) -> typing.Optional[builtins.bool]:
+        '''If this is set, the zip file will be synced to the destination S3 bucket and extracted.
+
+        If false, the file will remain zipped in the destination bucket.
+
+        :default: true
+        '''
+        result = self._values.get("extract")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def include(self) -> typing.Optional[typing.List[builtins.str]]:
         '''If this is set, matching files or objects will be included with the deployment's sync command.
@@ -933,7 +1031,7 @@ class BucketDeploymentProps:
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def metadata(self) -> typing.Optional["UserDefinedObjectMetadata"]:
+    def metadata(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         '''User-defined object metadata to be set on all objects in the deployment.
 
         :default: - No user metadata is set
@@ -941,7 +1039,7 @@ class BucketDeploymentProps:
         :see: https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingMetadata.html#UserMetadata
         '''
         result = self._values.get("metadata")
-        return typing.cast(typing.Optional["UserDefinedObjectMetadata"], result)
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
 
     @builtins.property
     def prune(self) -> typing.Optional[builtins.bool]:
@@ -1118,7 +1216,7 @@ class CacheControl(
         :param s: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CacheControl.from_string)
+            type_hints = typing.get_type_hints(_typecheckingstub__5378bf4b640b7a16c7706bd09f00794879ed5887b573039696c2f987de8de56d)
             check_type(argname="argument s", value=s, expected_type=type_hints["s"])
         return typing.cast("CacheControl", jsii.sinvoke(cls, "fromString", [s]))
 
@@ -1130,7 +1228,7 @@ class CacheControl(
         :param t: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CacheControl.max_age)
+            type_hints = typing.get_type_hints(_typecheckingstub__14f79d30bb247c06b3cb4a2320993bccd612f49f73aaef2c26c0ebedc35f9fb8)
             check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("CacheControl", jsii.sinvoke(cls, "maxAge", [t]))
 
@@ -1178,7 +1276,7 @@ class CacheControl(
         :param t: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CacheControl.s_max_age)
+            type_hints = typing.get_type_hints(_typecheckingstub__a96c203ed36a911c67a4356f7768a4928e9a7464835e49835710be73dc668b3d)
             check_type(argname="argument t", value=t, expected_type=type_hints["t"])
         return typing.cast("CacheControl", jsii.sinvoke(cls, "sMaxAge", [t]))
 
@@ -1216,9 +1314,9 @@ class DeploymentSourceContext:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DeploymentSourceContext.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__b7ffd3edc16757379a6161515d1c48008f74a9a937f09669c10cbcda3758a5a2)
             check_type(argname="argument handler_role", value=handler_role, expected_type=type_hints["handler_role"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "handler_role": handler_role,
         }
 
@@ -1248,7 +1346,7 @@ class ISource(typing_extensions.Protocol):
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         *,
         handler_role: _IRole_235f5d8e,
     ) -> "SourceConfig":
@@ -1268,7 +1366,7 @@ class _ISourceProxy:
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         *,
         handler_role: _IRole_235f5d8e,
     ) -> "SourceConfig":
@@ -1278,7 +1376,7 @@ class _ISourceProxy:
         :param handler_role: The role for the handler.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ISource.bind)
+            type_hints = typing.get_type_hints(_typecheckingstub__09970416699f317cf422c30f785da12ff6ed72f1358bc0e3e4adcf6e613fc748)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         context = DeploymentSourceContext(handler_role=handler_role)
 
@@ -1306,7 +1404,7 @@ class ServerSideEncryption(enum.Enum):
             sources=[s3deploy.Source.asset("./website-dist")],
             destination_bucket=website_bucket,
             destination_key_prefix="web/static",  # optional prefix in destination bucket
-            metadata=s3deploy.UserDefinedObjectMetadata(A="1", b="2"),  # user-defined metadata
+            metadata={"A": "1", "b": "2"},  # user-defined metadata
         
             # system-defined metadata
             content_type="text/html",
@@ -1332,11 +1430,12 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="aws-cdk-lib.aws_s3_deployment.S
 
     Usage::
 
-        Source.bucket(bucket, key)
-        Source.asset('/local/path/to/directory')
-        Source.asset('/local/path/to/a/file.zip')
-        Source.data('hello/world/file.txt', 'Hello, world!')
-        Source.data('config.json', { baz: topic.topicArn })
+       Source.bucket(bucket, key)
+       Source.asset('/local/path/to/directory')
+       Source.asset('/local/path/to/a/file.zip')
+       Source.data('hello/world/file.txt', 'Hello, world!')
+       Source.dataJson('config.json', { baz: topic.topicArn })
+       Source.dataYaml('config.yaml', { baz: topic.topicArn })
 
     :exampleMetadata: infused
 
@@ -1365,7 +1464,7 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="aws-cdk-lib.aws_s3_deployment.S
         readers: typing.Optional[typing.Sequence[_IGrantable_71c4f5de]] = None,
         asset_hash: typing.Optional[builtins.str] = None,
         asset_hash_type: typing.Optional[_AssetHashType_05b67f2d] = None,
-        bundling: typing.Optional[typing.Union[_BundlingOptions_588cc936, typing.Dict[str, typing.Any]]] = None,
+        bundling: typing.Optional[typing.Union[_BundlingOptions_588cc936, typing.Dict[builtins.str, typing.Any]]] = None,
         exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
         follow_symlinks: typing.Optional[_SymlinkFollowMode_047ec1f6] = None,
         ignore_mode: typing.Optional[_IgnoreMode_655a98e8] = None,
@@ -1385,7 +1484,7 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="aws-cdk-lib.aws_s3_deployment.S
         :param ignore_mode: The ignore behavior to use for ``exclude`` patterns. Default: IgnoreMode.GLOB
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Source.asset)
+            type_hints = typing.get_type_hints(_typecheckingstub__fc877c69568cee7364ec77003356fc6818118602dda64adf3dbf38ff7eec10b2)
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         options = _AssetOptions_2aa69621(
             readers=readers,
@@ -1410,7 +1509,7 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="aws-cdk-lib.aws_s3_deployment.S
         :param zip_object_key: The S3 object key of the zip file with contents.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Source.bucket)
+            type_hints = typing.get_type_hints(_typecheckingstub__bcaba123a95f1aa9d99f9f5af319da23dd5f345454e757ba9257364325b3efb5)
             check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
             check_type(argname="argument zip_object_key", value=zip_object_key, expected_type=type_hints["zip_object_key"])
         return typing.cast(ISource, jsii.sinvoke(cls, "bucket", [bucket, zip_object_key]))
@@ -1425,12 +1524,13 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="aws-cdk-lib.aws_s3_deployment.S
         will get resolved only during deployment.
 
         To store a JSON object use ``Source.jsonData()``.
+        To store YAML content use ``Source.yamlData()``.
 
         :param object_key: The destination S3 object key (relative to the root of the S3 deployment).
         :param data: The data to be stored in the object.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Source.data)
+            type_hints = typing.get_type_hints(_typecheckingstub__798b55b643d389adf599acde4d214b0b843e07f8c7984ea0e848f2da7c62822c)
             check_type(argname="argument object_key", value=object_key, expected_type=type_hints["object_key"])
             check_type(argname="argument data", value=data, expected_type=type_hints["data"])
         return typing.cast(ISource, jsii.sinvoke(cls, "data", [object_key, data]))
@@ -1448,11 +1548,28 @@ class Source(metaclass=jsii.JSIIMeta, jsii_type="aws-cdk-lib.aws_s3_deployment.S
         :param obj: A JSON object.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Source.json_data)
+            type_hints = typing.get_type_hints(_typecheckingstub__34bf47f9cf16464b2d85173fbce8786a1afe889c23001b8c7575c49e0bf93ff9)
             check_type(argname="argument object_key", value=object_key, expected_type=type_hints["object_key"])
             check_type(argname="argument obj", value=obj, expected_type=type_hints["obj"])
         return typing.cast(ISource, jsii.sinvoke(cls, "jsonData", [object_key, obj]))
 
+    @jsii.member(jsii_name="yamlData")
+    @builtins.classmethod
+    def yaml_data(cls, object_key: builtins.str, obj: typing.Any) -> ISource:
+        '''Deploys an object with the specified JSON object formatted as YAML into the bucket.
+
+        The object can include deploy-time values (such as ``snsTopic.topicArn``) that
+        will get resolved only during deployment.
+
+        :param object_key: The destination S3 object key (relative to the root of the S3 deployment).
+        :param obj: A JSON object.
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__bb0fa5367aafa7b8db0300fa69edeca060cb4ca66d1517ccc855345cc9bfe37e)
+            check_type(argname="argument object_key", value=object_key, expected_type=type_hints["object_key"])
+            check_type(argname="argument obj", value=obj, expected_type=type_hints["obj"])
+        return typing.cast(ISource, jsii.sinvoke(cls, "yamlData", [object_key, obj]))
+
 
 @jsii.data_type(
     jsii_type="aws-cdk-lib.aws_s3_deployment.SourceConfig",
@@ -1500,11 +1617,11 @@ class SourceConfig:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SourceConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__dafa1619bb92595ec0ff7aa95e55221719ed81eb6d2f7d44a84193d810c4265c)
             check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
             check_type(argname="argument zip_object_key", value=zip_object_key, expected_type=type_hints["zip_object_key"])
             check_type(argname="argument markers", value=markers, expected_type=type_hints["markers"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "bucket": bucket,
             "zip_object_key": zip_object_key,
         }
@@ -1564,7 +1681,7 @@ class StorageClass(enum.Enum):
             sources=[s3deploy.Source.asset("./website-dist")],
             destination_bucket=website_bucket,
             destination_key_prefix="web/static",  # optional prefix in destination bucket
-            metadata=s3deploy.UserDefinedObjectMetadata(A="1", b="2"),  # user-defined metadata
+            metadata={"A": "1", "b": "2"},  # user-defined metadata
         
             # system-defined metadata
             content_type="text/html",
@@ -1602,36 +1719,22 @@ class StorageClass(enum.Enum):
 )
 class UserDefinedObjectMetadata:
     def __init__(self) -> None:
-        '''Custom user defined metadata.
+        '''(deprecated) Custom user defined metadata.
 
-        :exampleMetadata: infused
+        :deprecated: Use raw property bags instead (object literals, ``Map<String,Object>``, etc... )
+
+        :stability: deprecated
+        :exampleMetadata: fixture=_generated
 
         Example::
 
-            website_bucket = s3.Bucket(self, "WebsiteBucket",
-                website_index_document="index.html",
-                public_read_access=True
-            )
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            from aws_cdk import aws_s3_deployment as s3_deployment
             
-            s3deploy.BucketDeployment(self, "DeployWebsite",
-                sources=[s3deploy.Source.asset("./website-dist")],
-                destination_bucket=website_bucket,
-                destination_key_prefix="web/static",  # optional prefix in destination bucket
-                metadata=s3deploy.UserDefinedObjectMetadata(A="1", b="2"),  # user-defined metadata
-            
-                # system-defined metadata
-                content_type="text/html",
-                content_language="en",
-                storage_class=s3deploy.StorageClass.INTELLIGENT_TIERING,
-                server_side_encryption=s3deploy.ServerSideEncryption.AES_256,
-                cache_control=[
-                    s3deploy.CacheControl.set_public(),
-                    s3deploy.CacheControl.max_age(Duration.hours(1))
-                ],
-                access_control=s3.BucketAccessControl.BUCKET_OWNER_FULL_CONTROL
-            )
+            user_defined_object_metadata = s3_deployment.UserDefinedObjectMetadata()
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -1659,3 +1762,167 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__2544491e92aa50a255b927ef16b9cde2961eae48803afca3b5d1105bfc3398f1(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    destination_bucket: _IBucket_42e086fd,
+    sources: typing.Sequence[ISource],
+    access_control: typing.Optional[_BucketAccessControl_466c7e1b] = None,
+    cache_control: typing.Optional[typing.Sequence[CacheControl]] = None,
+    content_disposition: typing.Optional[builtins.str] = None,
+    content_encoding: typing.Optional[builtins.str] = None,
+    content_language: typing.Optional[builtins.str] = None,
+    content_type: typing.Optional[builtins.str] = None,
+    destination_key_prefix: typing.Optional[builtins.str] = None,
+    distribution: typing.Optional[_IDistribution_7ac752a4] = None,
+    distribution_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
+    ephemeral_storage_size: typing.Optional[_Size_7b441c34] = None,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    expires: typing.Optional[_Expiration_059d47d0] = None,
+    extract: typing.Optional[builtins.bool] = None,
+    include: typing.Optional[typing.Sequence[builtins.str]] = None,
+    log_retention: typing.Optional[_RetentionDays_070f99f0] = None,
+    memory_limit: typing.Optional[jsii.Number] = None,
+    metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    prune: typing.Optional[builtins.bool] = None,
+    retain_on_delete: typing.Optional[builtins.bool] = None,
+    role: typing.Optional[_IRole_235f5d8e] = None,
+    server_side_encryption: typing.Optional[ServerSideEncryption] = None,
+    server_side_encryption_aws_kms_key_id: typing.Optional[builtins.str] = None,
+    server_side_encryption_customer_algorithm: typing.Optional[builtins.str] = None,
+    storage_class: typing.Optional[StorageClass] = None,
+    use_efs: typing.Optional[builtins.bool] = None,
+    vpc: typing.Optional[_IVpc_f30d5663] = None,
+    vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[builtins.str, typing.Any]]] = None,
+    website_redirect_location: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cfc987787f1589c85fbb65eaf66aaf15684268f9d214e1a0278f52c99e907028(
+    source: ISource,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cbabf07e8b4adfb2b2058c075c4f35512ebc580f80a6db9bf13e905898822551(
+    *,
+    destination_bucket: _IBucket_42e086fd,
+    sources: typing.Sequence[ISource],
+    access_control: typing.Optional[_BucketAccessControl_466c7e1b] = None,
+    cache_control: typing.Optional[typing.Sequence[CacheControl]] = None,
+    content_disposition: typing.Optional[builtins.str] = None,
+    content_encoding: typing.Optional[builtins.str] = None,
+    content_language: typing.Optional[builtins.str] = None,
+    content_type: typing.Optional[builtins.str] = None,
+    destination_key_prefix: typing.Optional[builtins.str] = None,
+    distribution: typing.Optional[_IDistribution_7ac752a4] = None,
+    distribution_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
+    ephemeral_storage_size: typing.Optional[_Size_7b441c34] = None,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    expires: typing.Optional[_Expiration_059d47d0] = None,
+    extract: typing.Optional[builtins.bool] = None,
+    include: typing.Optional[typing.Sequence[builtins.str]] = None,
+    log_retention: typing.Optional[_RetentionDays_070f99f0] = None,
+    memory_limit: typing.Optional[jsii.Number] = None,
+    metadata: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    prune: typing.Optional[builtins.bool] = None,
+    retain_on_delete: typing.Optional[builtins.bool] = None,
+    role: typing.Optional[_IRole_235f5d8e] = None,
+    server_side_encryption: typing.Optional[ServerSideEncryption] = None,
+    server_side_encryption_aws_kms_key_id: typing.Optional[builtins.str] = None,
+    server_side_encryption_customer_algorithm: typing.Optional[builtins.str] = None,
+    storage_class: typing.Optional[StorageClass] = None,
+    use_efs: typing.Optional[builtins.bool] = None,
+    vpc: typing.Optional[_IVpc_f30d5663] = None,
+    vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[builtins.str, typing.Any]]] = None,
+    website_redirect_location: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5378bf4b640b7a16c7706bd09f00794879ed5887b573039696c2f987de8de56d(
+    s: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__14f79d30bb247c06b3cb4a2320993bccd612f49f73aaef2c26c0ebedc35f9fb8(
+    t: _Duration_4839e8c3,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a96c203ed36a911c67a4356f7768a4928e9a7464835e49835710be73dc668b3d(
+    t: _Duration_4839e8c3,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b7ffd3edc16757379a6161515d1c48008f74a9a937f09669c10cbcda3758a5a2(
+    *,
+    handler_role: _IRole_235f5d8e,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__09970416699f317cf422c30f785da12ff6ed72f1358bc0e3e4adcf6e613fc748(
+    scope: _constructs_77d1e7e8.Construct,
+    *,
+    handler_role: _IRole_235f5d8e,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fc877c69568cee7364ec77003356fc6818118602dda64adf3dbf38ff7eec10b2(
+    path: builtins.str,
+    *,
+    readers: typing.Optional[typing.Sequence[_IGrantable_71c4f5de]] = None,
+    asset_hash: typing.Optional[builtins.str] = None,
+    asset_hash_type: typing.Optional[_AssetHashType_05b67f2d] = None,
+    bundling: typing.Optional[typing.Union[_BundlingOptions_588cc936, typing.Dict[builtins.str, typing.Any]]] = None,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    follow_symlinks: typing.Optional[_SymlinkFollowMode_047ec1f6] = None,
+    ignore_mode: typing.Optional[_IgnoreMode_655a98e8] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bcaba123a95f1aa9d99f9f5af319da23dd5f345454e757ba9257364325b3efb5(
+    bucket: _IBucket_42e086fd,
+    zip_object_key: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__798b55b643d389adf599acde4d214b0b843e07f8c7984ea0e848f2da7c62822c(
+    object_key: builtins.str,
+    data: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__34bf47f9cf16464b2d85173fbce8786a1afe889c23001b8c7575c49e0bf93ff9(
+    object_key: builtins.str,
+    obj: typing.Any,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bb0fa5367aafa7b8db0300fa69edeca060cb4ca66d1517ccc855345cc9bfe37e(
+    object_key: builtins.str,
+    obj: typing.Any,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dafa1619bb92595ec0ff7aa95e55221719ed81eb6d2f7d44a84193d810c4265c(
+    *,
+    bucket: _IBucket_42e086fd,
+    zip_object_key: builtins.str,
+    markers: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
