@@ -495,6 +495,10 @@ aws_custom = cr.AwsCustomResource(self, "aws-custom",
 )
 ```
 
+You can omit `PhysicalResourceId` property in `onUpdate` to passthrough the value in `onCreate`. This behavior is useful when using Update APIs that response with an empty body.
+
+> AwsCustomResource.getResponseField() and .getResponseFieldReference() will not work if the Create and Update APIs don't consistently return the same fields.
+
 ### Handling Custom Resource Errors
 
 Every error produced by the API call is treated as is and will cause a "FAILED" response to be submitted to CloudFormation.
@@ -639,7 +643,7 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from .. import (
     Duration as _Duration_4839e8c3,
     IResolvable as _IResolvable_da3f097b,
@@ -663,7 +667,7 @@ from ..aws_logs import RetentionDays as _RetentionDays_070f99f0
 
 @jsii.implements(_IGrantable_71c4f5de)
 class AwsCustomResource(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="aws-cdk-lib.custom_resources.AwsCustomResource",
 ):
@@ -699,27 +703,27 @@ class AwsCustomResource(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         function_name: typing.Optional[builtins.str] = None,
         install_latest_aws_sdk: typing.Optional[builtins.bool] = None,
         log_retention: typing.Optional[_RetentionDays_070f99f0] = None,
-        on_create: typing.Optional[typing.Union["AwsSdkCall", typing.Dict[str, typing.Any]]] = None,
-        on_delete: typing.Optional[typing.Union["AwsSdkCall", typing.Dict[str, typing.Any]]] = None,
-        on_update: typing.Optional[typing.Union["AwsSdkCall", typing.Dict[str, typing.Any]]] = None,
+        on_create: typing.Optional[typing.Union["AwsSdkCall", typing.Dict[builtins.str, typing.Any]]] = None,
+        on_delete: typing.Optional[typing.Union["AwsSdkCall", typing.Dict[builtins.str, typing.Any]]] = None,
+        on_update: typing.Optional[typing.Union["AwsSdkCall", typing.Dict[builtins.str, typing.Any]]] = None,
         policy: typing.Optional["AwsCustomResourcePolicy"] = None,
         resource_type: typing.Optional[builtins.str] = None,
         role: typing.Optional[_IRole_235f5d8e] = None,
         timeout: typing.Optional[_Duration_4839e8c3] = None,
         vpc: typing.Optional[_IVpc_f30d5663] = None,
-        vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[str, typing.Any]]] = None,
+        vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
         :param function_name: A name for the singleton Lambda function implementing this custom resource. The function name will remain the same after the first AwsCustomResource is created in a stack. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
-        :param install_latest_aws_sdk: Whether to install the latest AWS SDK v2. Allows to use the latest API calls documented at https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/index.html. The installation takes around 60 seconds. Default: true
+        :param install_latest_aws_sdk: Whether to install the latest AWS SDK v2. If not specified, this uses whatever JavaScript SDK version is the default in AWS Lambda at the time of execution. Otherwise, installs the latest version from 'npmjs.com'. The installation takes around 60 seconds and requires internet connectivity. The default can be controlled using the context key ``@aws-cdk/customresources:installLatestAwsSdkDefault`` is. Default: - The value of ``@aws-cdk/customresources:installLatestAwsSdkDefault``, otherwise ``true``
         :param log_retention: The number of days log events of the singleton Lambda function implementing this custom resource are kept in CloudWatch Logs. Default: logs.RetentionDays.INFINITE
         :param on_create: The AWS SDK call to make when the resource is created. Default: - the call when the resource is updated
         :param on_delete: The AWS SDK call to make when the resource is deleted. Default: - no call
@@ -732,7 +736,7 @@ class AwsCustomResource(
         :param vpc_subnets: Which subnets from the VPC to place the lambda function in. Only used if 'vpc' is supplied. Note: internet access for Lambdas requires a NAT gateway, so picking Public subnets is not allowed. Default: - the Vpc default strategy if not specified
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsCustomResource.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__4b163f566913e92c7adaa1ea97e50050b801bd514d3b2f5e3ddf86c11297e862)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = AwsCustomResourceProps(
@@ -765,7 +769,7 @@ class AwsCustomResource(
         :param data_path: the path to the data.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsCustomResource.get_response_field)
+            type_hints = typing.get_type_hints(_typecheckingstub__3a62242b1380cc5a46c343b8beb355b12ad4bead7d218dff7533f32ef95535dc)
             check_type(argname="argument data_path", value=data_path, expected_type=type_hints["data_path"])
         return typing.cast(builtins.str, jsii.invoke(self, "getResponseField", [data_path]))
 
@@ -788,10 +792,16 @@ class AwsCustomResource(
         :param data_path: the path to the data.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsCustomResource.get_response_field_reference)
+            type_hints = typing.get_type_hints(_typecheckingstub__8a3cb7c74c2f60a8f1c2cfe429816d6751f4abf9bd7f2fccca230d2e342d4c5e)
             check_type(argname="argument data_path", value=data_path, expected_type=type_hints["data_path"])
         return typing.cast(_Reference_6ab8bd04, jsii.invoke(self, "getResponseFieldReference", [data_path]))
 
+    @jsii.python.classproperty
+    @jsii.member(jsii_name="PROVIDER_FUNCTION_UUID")
+    def PROVIDER_FUNCTION_UUID(cls) -> builtins.str:
+        '''The uuid of the custom resource provider singleton lambda function.'''
+        return typing.cast(builtins.str, jsii.sget(cls, "PROVIDER_FUNCTION_UUID"))
+
     @builtins.property
     @jsii.member(jsii_name="grantPrincipal")
     def grant_principal(self) -> _IPrincipal_539bb2fd:
@@ -862,7 +872,7 @@ class AwsCustomResourcePolicy(
         :param statements: the statements to propagate to the SDK calls.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsCustomResourcePolicy.from_statements)
+            type_hints = typing.get_type_hints(_typecheckingstub__267132a8dbe09112fac8abcec56b61816ca5265080c0657023e152ec4eff48b1)
             check_type(argname="argument statements", value=statements, expected_type=type_hints["statements"])
         return typing.cast("AwsCustomResourcePolicy", jsii.sinvoke(cls, "fromStatements", [statements]))
 
@@ -910,22 +920,22 @@ class AwsCustomResourceProps:
         function_name: typing.Optional[builtins.str] = None,
         install_latest_aws_sdk: typing.Optional[builtins.bool] = None,
         log_retention: typing.Optional[_RetentionDays_070f99f0] = None,
-        on_create: typing.Optional[typing.Union["AwsSdkCall", typing.Dict[str, typing.Any]]] = None,
-        on_delete: typing.Optional[typing.Union["AwsSdkCall", typing.Dict[str, typing.Any]]] = None,
-        on_update: typing.Optional[typing.Union["AwsSdkCall", typing.Dict[str, typing.Any]]] = None,
+        on_create: typing.Optional[typing.Union["AwsSdkCall", typing.Dict[builtins.str, typing.Any]]] = None,
+        on_delete: typing.Optional[typing.Union["AwsSdkCall", typing.Dict[builtins.str, typing.Any]]] = None,
+        on_update: typing.Optional[typing.Union["AwsSdkCall", typing.Dict[builtins.str, typing.Any]]] = None,
         policy: typing.Optional[AwsCustomResourcePolicy] = None,
         resource_type: typing.Optional[builtins.str] = None,
         role: typing.Optional[_IRole_235f5d8e] = None,
         timeout: typing.Optional[_Duration_4839e8c3] = None,
         vpc: typing.Optional[_IVpc_f30d5663] = None,
-        vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[str, typing.Any]]] = None,
+        vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''Properties for AwsCustomResource.
 
         Note that at least onCreate, onUpdate or onDelete must be specified.
 
         :param function_name: A name for the singleton Lambda function implementing this custom resource. The function name will remain the same after the first AwsCustomResource is created in a stack. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
-        :param install_latest_aws_sdk: Whether to install the latest AWS SDK v2. Allows to use the latest API calls documented at https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/index.html. The installation takes around 60 seconds. Default: true
+        :param install_latest_aws_sdk: Whether to install the latest AWS SDK v2. If not specified, this uses whatever JavaScript SDK version is the default in AWS Lambda at the time of execution. Otherwise, installs the latest version from 'npmjs.com'. The installation takes around 60 seconds and requires internet connectivity. The default can be controlled using the context key ``@aws-cdk/customresources:installLatestAwsSdkDefault`` is. Default: - The value of ``@aws-cdk/customresources:installLatestAwsSdkDefault``, otherwise ``true``
         :param log_retention: The number of days log events of the singleton Lambda function implementing this custom resource are kept in CloudWatch Logs. Default: logs.RetentionDays.INFINITE
         :param on_create: The AWS SDK call to make when the resource is created. Default: - the call when the resource is updated
         :param on_delete: The AWS SDK call to make when the resource is deleted. Default: - no call
@@ -967,7 +977,7 @@ class AwsCustomResourceProps:
         if isinstance(vpc_subnets, dict):
             vpc_subnets = _SubnetSelection_e57d76df(**vpc_subnets)
         if __debug__:
-            type_hints = typing.get_type_hints(AwsCustomResourceProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__2b5a9dace9a09081edfef936656f2d5670f198fb300a32c31957c93e5bb08c2f)
             check_type(argname="argument function_name", value=function_name, expected_type=type_hints["function_name"])
             check_type(argname="argument install_latest_aws_sdk", value=install_latest_aws_sdk, expected_type=type_hints["install_latest_aws_sdk"])
             check_type(argname="argument log_retention", value=log_retention, expected_type=type_hints["log_retention"])
@@ -980,7 +990,7 @@ class AwsCustomResourceProps:
             check_type(argname="argument timeout", value=timeout, expected_type=type_hints["timeout"])
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
             check_type(argname="argument vpc_subnets", value=vpc_subnets, expected_type=type_hints["vpc_subnets"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if function_name is not None:
             self._values["function_name"] = function_name
         if install_latest_aws_sdk is not None:
@@ -1022,11 +1032,18 @@ class AwsCustomResourceProps:
 
     @builtins.property
     def install_latest_aws_sdk(self) -> typing.Optional[builtins.bool]:
-        '''Whether to install the latest AWS SDK v2. Allows to use the latest API calls documented at https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/index.html.
+        '''Whether to install the latest AWS SDK v2.
 
-        The installation takes around 60 seconds.
+        If not specified, this uses whatever JavaScript SDK version is the default in
+        AWS Lambda at the time of execution.
 
-        :default: true
+        Otherwise, installs the latest version from 'npmjs.com'. The installation takes
+        around 60 seconds and requires internet connectivity.
+
+        The default can be controlled using the context key
+        ``@aws-cdk/customresources:installLatestAwsSdkDefault`` is.
+
+        :default: - The value of ``@aws-cdk/customresources:installLatestAwsSdkDefault``, otherwise ``true``
         '''
         result = self._values.get("install_latest_aws_sdk")
         return typing.cast(typing.Optional[builtins.bool], result)
@@ -1191,7 +1208,7 @@ class AwsSdkCall:
         :param ignore_error_codes_matching: The regex pattern to use to catch API errors. The ``code`` property of the ``Error`` object will be tested against this pattern. If there is a match an error will not be thrown. Default: - do not catch errors
         :param output_paths: Restrict the data returned by the custom resource to specific paths in the API response. Use this to limit the data returned by the custom resource if working with API calls that could potentially result in custom response objects exceeding the hard limit of 4096 bytes. Example for ECS / updateService: ['service.deploymentConfiguration.maximumPercent'] Default: - return all data
         :param parameters: The parameters for the service action. Default: - no parameters
-        :param physical_resource_id: The physical resource id of the custom resource for this call. Mandatory for onCreate or onUpdate calls. Default: - no physical resource id
+        :param physical_resource_id: The physical resource id of the custom resource for this call. Mandatory for onCreate call. In onUpdate, you can omit this to passthrough it from request. Default: - no physical resource id
         :param region: The region to send service requests to. **Note: Cross-region operations are generally considered an anti-pattern.** **Consider first deploying a stack in that region.** Default: - the region where this custom resource is deployed
 
         :exampleMetadata: infused
@@ -1221,7 +1238,7 @@ class AwsSdkCall:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsSdkCall.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__af7bb124668b93c6ce7d641df2daeabfe424e271742385a76e7e56ec91c39dc9)
             check_type(argname="argument action", value=action, expected_type=type_hints["action"])
             check_type(argname="argument service", value=service, expected_type=type_hints["service"])
             check_type(argname="argument api_version", value=api_version, expected_type=type_hints["api_version"])
@@ -1231,7 +1248,7 @@ class AwsSdkCall:
             check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
             check_type(argname="argument physical_resource_id", value=physical_resource_id, expected_type=type_hints["physical_resource_id"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "action": action,
             "service": service,
         }
@@ -1335,7 +1352,8 @@ class AwsSdkCall:
     def physical_resource_id(self) -> typing.Optional["PhysicalResourceId"]:
         '''The physical resource id of the custom resource for this call.
 
-        Mandatory for onCreate or onUpdate calls.
+        Mandatory for onCreate call.
+        In onUpdate, you can omit this to passthrough it from request.
 
         :default: - no physical resource id
         '''
@@ -1407,7 +1425,7 @@ class PhysicalResourceId(
         :param response_path: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PhysicalResourceId.from_response)
+            type_hints = typing.get_type_hints(_typecheckingstub__6baa8764ccdf77f11bd8f80af9fafec69f56b719c1a237caae55c7f988e174b6)
             check_type(argname="argument response_path", value=response_path, expected_type=type_hints["response_path"])
         return typing.cast("PhysicalResourceId", jsii.sinvoke(cls, "fromResponse", [response_path]))
 
@@ -1419,7 +1437,7 @@ class PhysicalResourceId(
         :param id: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PhysicalResourceId.of)
+            type_hints = typing.get_type_hints(_typecheckingstub__bdca735a77f74ade2070f6a3cbaf95d939ee16657cec7f53ec60b2df0a096bd2)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         return typing.cast("PhysicalResourceId", jsii.sinvoke(cls, "of", [id]))
 
@@ -1480,7 +1498,7 @@ class PhysicalResourceIdReference(
         :param _: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PhysicalResourceIdReference.resolve)
+            type_hints = typing.get_type_hints(_typecheckingstub__784d4e05d144bc71f705b7f70440a6f66fee012cf9cf6f0bea5bbf88c7b49fd7)
             check_type(argname="argument _", value=_, expected_type=type_hints["_"])
         return typing.cast(typing.Any, jsii.invoke(self, "resolve", [_]))
 
@@ -1509,7 +1527,7 @@ class PhysicalResourceIdReference(
 
 
 class Provider(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="aws-cdk-lib.custom_resources.Provider",
 ):
@@ -1534,7 +1552,7 @@ class Provider(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         on_event_handler: _IFunction_6adb0ab8,
@@ -1546,7 +1564,7 @@ class Provider(
         security_groups: typing.Optional[typing.Sequence[_ISecurityGroup_acf8a799]] = None,
         total_timeout: typing.Optional[_Duration_4839e8c3] = None,
         vpc: typing.Optional[_IVpc_f30d5663] = None,
-        vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[str, typing.Any]]] = None,
+        vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -1563,7 +1581,7 @@ class Provider(
         :param vpc_subnets: Which subnets from the VPC to place the lambda functions in. Only used if 'vpc' is supplied. Note: internet access for Lambdas requires a NAT gateway, so picking Public subnets is not allowed. Default: - the Vpc default strategy if not specified
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Provider.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__29415d7bf7977fcf110b77ce69cec309dcf0404601944735020770ddfe2b01a8)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ProviderProps(
@@ -1629,7 +1647,7 @@ class ProviderProps:
         security_groups: typing.Optional[typing.Sequence[_ISecurityGroup_acf8a799]] = None,
         total_timeout: typing.Optional[_Duration_4839e8c3] = None,
         vpc: typing.Optional[_IVpc_f30d5663] = None,
-        vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[str, typing.Any]]] = None,
+        vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''Initialization properties for the ``Provider`` construct.
 
@@ -1663,7 +1681,7 @@ class ProviderProps:
         if isinstance(vpc_subnets, dict):
             vpc_subnets = _SubnetSelection_e57d76df(**vpc_subnets)
         if __debug__:
-            type_hints = typing.get_type_hints(ProviderProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__32b03803ee02437d8d83814282c700ede5633030e4d9f7ebdaf3b9d075b0cbdb)
             check_type(argname="argument on_event_handler", value=on_event_handler, expected_type=type_hints["on_event_handler"])
             check_type(argname="argument is_complete_handler", value=is_complete_handler, expected_type=type_hints["is_complete_handler"])
             check_type(argname="argument log_retention", value=log_retention, expected_type=type_hints["log_retention"])
@@ -1674,7 +1692,7 @@ class ProviderProps:
             check_type(argname="argument total_timeout", value=total_timeout, expected_type=type_hints["total_timeout"])
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
             check_type(argname="argument vpc_subnets", value=vpc_subnets, expected_type=type_hints["vpc_subnets"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "on_event_handler": on_event_handler,
         }
         if is_complete_handler is not None:
@@ -1866,9 +1884,9 @@ class SdkCallsPolicyOptions:
             get_parameter.get_response_field("Parameter.Value")
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(SdkCallsPolicyOptions.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__0cd00e8add38e42b6c4d7db0390a899ccaf5bbe0367bfb387986125dacc7a297)
             check_type(argname="argument resources", value=resources, expected_type=type_hints["resources"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "resources": resources,
         }
 
@@ -1911,3 +1929,133 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__4b163f566913e92c7adaa1ea97e50050b801bd514d3b2f5e3ddf86c11297e862(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    function_name: typing.Optional[builtins.str] = None,
+    install_latest_aws_sdk: typing.Optional[builtins.bool] = None,
+    log_retention: typing.Optional[_RetentionDays_070f99f0] = None,
+    on_create: typing.Optional[typing.Union[AwsSdkCall, typing.Dict[builtins.str, typing.Any]]] = None,
+    on_delete: typing.Optional[typing.Union[AwsSdkCall, typing.Dict[builtins.str, typing.Any]]] = None,
+    on_update: typing.Optional[typing.Union[AwsSdkCall, typing.Dict[builtins.str, typing.Any]]] = None,
+    policy: typing.Optional[AwsCustomResourcePolicy] = None,
+    resource_type: typing.Optional[builtins.str] = None,
+    role: typing.Optional[_IRole_235f5d8e] = None,
+    timeout: typing.Optional[_Duration_4839e8c3] = None,
+    vpc: typing.Optional[_IVpc_f30d5663] = None,
+    vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3a62242b1380cc5a46c343b8beb355b12ad4bead7d218dff7533f32ef95535dc(
+    data_path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8a3cb7c74c2f60a8f1c2cfe429816d6751f4abf9bd7f2fccca230d2e342d4c5e(
+    data_path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__267132a8dbe09112fac8abcec56b61816ca5265080c0657023e152ec4eff48b1(
+    statements: typing.Sequence[_PolicyStatement_0fe33853],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2b5a9dace9a09081edfef936656f2d5670f198fb300a32c31957c93e5bb08c2f(
+    *,
+    function_name: typing.Optional[builtins.str] = None,
+    install_latest_aws_sdk: typing.Optional[builtins.bool] = None,
+    log_retention: typing.Optional[_RetentionDays_070f99f0] = None,
+    on_create: typing.Optional[typing.Union[AwsSdkCall, typing.Dict[builtins.str, typing.Any]]] = None,
+    on_delete: typing.Optional[typing.Union[AwsSdkCall, typing.Dict[builtins.str, typing.Any]]] = None,
+    on_update: typing.Optional[typing.Union[AwsSdkCall, typing.Dict[builtins.str, typing.Any]]] = None,
+    policy: typing.Optional[AwsCustomResourcePolicy] = None,
+    resource_type: typing.Optional[builtins.str] = None,
+    role: typing.Optional[_IRole_235f5d8e] = None,
+    timeout: typing.Optional[_Duration_4839e8c3] = None,
+    vpc: typing.Optional[_IVpc_f30d5663] = None,
+    vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__af7bb124668b93c6ce7d641df2daeabfe424e271742385a76e7e56ec91c39dc9(
+    *,
+    action: builtins.str,
+    service: builtins.str,
+    api_version: typing.Optional[builtins.str] = None,
+    assumed_role_arn: typing.Optional[builtins.str] = None,
+    ignore_error_codes_matching: typing.Optional[builtins.str] = None,
+    output_paths: typing.Optional[typing.Sequence[builtins.str]] = None,
+    parameters: typing.Any = None,
+    physical_resource_id: typing.Optional[PhysicalResourceId] = None,
+    region: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6baa8764ccdf77f11bd8f80af9fafec69f56b719c1a237caae55c7f988e174b6(
+    response_path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bdca735a77f74ade2070f6a3cbaf95d939ee16657cec7f53ec60b2df0a096bd2(
+    id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__784d4e05d144bc71f705b7f70440a6f66fee012cf9cf6f0bea5bbf88c7b49fd7(
+    _: _IResolveContext_b2df1921,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__29415d7bf7977fcf110b77ce69cec309dcf0404601944735020770ddfe2b01a8(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    on_event_handler: _IFunction_6adb0ab8,
+    is_complete_handler: typing.Optional[_IFunction_6adb0ab8] = None,
+    log_retention: typing.Optional[_RetentionDays_070f99f0] = None,
+    provider_function_name: typing.Optional[builtins.str] = None,
+    query_interval: typing.Optional[_Duration_4839e8c3] = None,
+    role: typing.Optional[_IRole_235f5d8e] = None,
+    security_groups: typing.Optional[typing.Sequence[_ISecurityGroup_acf8a799]] = None,
+    total_timeout: typing.Optional[_Duration_4839e8c3] = None,
+    vpc: typing.Optional[_IVpc_f30d5663] = None,
+    vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__32b03803ee02437d8d83814282c700ede5633030e4d9f7ebdaf3b9d075b0cbdb(
+    *,
+    on_event_handler: _IFunction_6adb0ab8,
+    is_complete_handler: typing.Optional[_IFunction_6adb0ab8] = None,
+    log_retention: typing.Optional[_RetentionDays_070f99f0] = None,
+    provider_function_name: typing.Optional[builtins.str] = None,
+    query_interval: typing.Optional[_Duration_4839e8c3] = None,
+    role: typing.Optional[_IRole_235f5d8e] = None,
+    security_groups: typing.Optional[typing.Sequence[_ISecurityGroup_acf8a799]] = None,
+    total_timeout: typing.Optional[_Duration_4839e8c3] = None,
+    vpc: typing.Optional[_IVpc_f30d5663] = None,
+    vpc_subnets: typing.Optional[typing.Union[_SubnetSelection_e57d76df, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0cd00e8add38e42b6c4d7db0390a899ccaf5bbe0367bfb387986125dacc7a297(
+    *,
+    resources: typing.Sequence[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
